@@ -12,7 +12,7 @@ from ipaddress import (
     _BaseNetwork,
 )
 from pathlib import Path
-from typing import TYPE_CHECKING, Any, Dict, Generator, Optional, Pattern, Set, Tuple, Type, Union, cast
+from typing import TYPE_CHECKING, Any, Callable, Dict, Generator, Optional, Pattern, Set, Tuple, Type, Union, cast
 from uuid import UUID
 
 from . import errors
@@ -74,6 +74,8 @@ __all__ = [
     'IPvAnyAddress',
     'IPvAnyInterface',
     'IPvAnyNetwork',
+    'SecretStr',
+    'SecretBytes',
 ]
 
 NoneStr = Optional[str]
@@ -87,9 +89,12 @@ NetworkType = Union[str, bytes, int, Tuple[Union[str, bytes, int], Union[str, in
 
 
 if TYPE_CHECKING:  # pragma: no cover
+    from .dataclasses import DataclassType  # noqa: F401
+    from .main import BaseModel  # noqa: F401
     from .utils import AnyCallable
 
     CallableGenerator = Generator[AnyCallable, None, None]
+    ModelOrDc = Type[Union['BaseModel', 'DataclassType']]
 
 
 class StrictStr(str):
@@ -268,11 +273,18 @@ class PyObject:
 
     @classmethod
     def __get_validators__(cls) -> 'CallableGenerator':
-        yield str_validator
         yield cls.validate
 
     @classmethod
     def validate(cls, value: Any) -> Any:
+        if isinstance(value, Callable):  # type: ignore
+            return value
+
+        try:
+            value = str_validator(value)
+        except errors.StrError:
+            raise errors.PyObjectError(error_message='value is neither a valid import path not a valid callable')
+
         if value is not None:
             try:
                 return import_string(value)
@@ -562,3 +574,55 @@ class IPvAnyNetwork(_BaseNetwork):  # type: ignore
 
         with change_exception(errors.IPvAnyNetworkError, ValueError):
             return IPv6Network(value)
+
+
+class SecretStr:
+    @classmethod
+    def __get_validators__(cls) -> 'CallableGenerator':
+        yield str_validator
+        yield cls.validate
+
+    @classmethod
+    def validate(cls, value: str) -> 'SecretStr':
+        return cls(value)
+
+    def __init__(self, value: str):
+        self._secret_value = value
+
+    def __repr__(self) -> str:
+        return "SecretStr('**********')" if self._secret_value else "SecretStr('')"
+
+    def __str__(self) -> str:
+        return repr(self)
+
+    def display(self) -> str:
+        return '**********' if self._secret_value else ''
+
+    def get_secret_value(self) -> str:
+        return self._secret_value
+
+
+class SecretBytes:
+    @classmethod
+    def __get_validators__(cls) -> 'CallableGenerator':
+        yield bytes_validator
+        yield cls.validate
+
+    @classmethod
+    def validate(cls, value: bytes) -> 'SecretBytes':
+        return cls(value)
+
+    def __init__(self, value: bytes):
+        self._secret_value = value
+
+    def __repr__(self) -> str:
+        return "SecretBytes(b'**********')" if self._secret_value else "SecretBytes(b'')"
+
+    def __str__(self) -> str:
+        return repr(self)
+
+    def display(self) -> str:
+        return '**********' if self._secret_value else ''
+
+    def get_secret_value(self) -> bytes:
+        return self._secret_value
